@@ -28,7 +28,7 @@ extern char *getlamer(char *);
 extern char *getchanmode(char *);
 extern char *getchankey(char *);
 extern char *getchanflags(char *);
-extern char *safeban(char *);
+extern char *safeban(char *, char *, char *);
 extern char *getfirsthostless(char *);
 extern char *isnickbk(char *, char *);
 extern char *getkickreason(char *);
@@ -115,6 +115,7 @@ extern int getrandommsg(char *, char *, int, int, char *, int);
 extern int getjoincount(char *, char *);
 extern int lastquote(char *);
 extern int delserver(char *, int, int, int, int, int);
+extern int deladverts(char *, char *);
 extern int setpassword(char *, char *, char *);
 extern int logoff(char *, char *);
 extern int logon(char *, char *, char *, char *, int);
@@ -148,10 +149,9 @@ extern struct topic *addnewtopic(char *, char *, char *);
 extern struct topic *insertnewtopic(char *, char *, char *, int);
 extern struct topic *edittopic(char *, char *, char *, int);
 extern struct chanuser *getrandomuser(char *);
-extern struct ls_wrapstruct *addnew_ls(struct ls_wrapstruct *, time_t, char *, char *, char *);
+extern struct ls_wrapstruct *addnew_ls(struct ls_wrapstruct *, int, time_t, char *, char *, char *);
 extern time_t lastoff(char *, char *, char *);
 extern void sendadverts(char *, char *, char *);
-extern void deladverts(char *, char *);
 extern void resetparts(char *, char *, char *);
 extern void iamop(char *, int);
 extern void initpubmsgs(char *);
