@@ -231,12 +231,15 @@ enum OER_DEBUG_LEVELS {
 	OER_DEBUG_FLOOD = 9
 };
 
-enum OER_ADVERT_TYPES {
-	OER_ADVERT_TYPE_LAMERS,
-	OER_ADVERT_TYPE_BOTUSERS_OPS,
-	OER_ADVERT_TYPE_BOTUSERS_ADMINS,
-	OER_ADVERT_TYPE_BOTUSERS_OTHER,
-	OER_ADVERT_TYPE_INVALID
+enum OER_BAN_TYPES {
+	OER_BAN_TYPE_HOST = 1,
+	OER_BAN_TYPE_USER,
+	OER_BAN_TYPE_USER_HOST,
+	OER_BAN_TYPE_NICK,
+	OER_BAN_TYPE_NICK_HOST,
+	OER_BAN_TYPE_NICK_USER,
+	OER_BAN_TYPE_NICK_USER_HOST,
+	OER_BAN_TYPE_INVALID
 };
 
 #define numofparams(x) (wordcount(x) - 1)
@@ -269,13 +272,16 @@ enum OER_ADVERT_TYPES {
 #define OER_QUOTE_INTERVAL 300
 #define OER_ALLOWED_PARTS OER_PARTS / 5
 #define OER_RECONNECT_DELAY 30
+#define OER_NETJOIN_DELAY 15
 #define OER_PUBMSGS 20
 #define OER_TOPICS 10
 #define OER_SERVER_IS_STONED_FOR 300
 #define OER_MASSMODE_LIMIT 3
-#define OER_LASTS 3
+#define OER_LAST 3
+#define OER_LAST_MAX 10
 #define OER_LAST_MAX_LENGTH 120
 #define OER_SEEN 3
+#define OER_SEEN_MAX 10
 #define OER_PERMBANS 25
 #define OER_LOGON_TIMEOUT 1800
 #define OER_BANVARS_AUTO_REJOIN 30
@@ -319,7 +325,7 @@ enum OER_ADVERT_TYPES {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-38, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-39, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -354,7 +360,7 @@ struct locked {
 
 struct chanuser {
 	char *nick;
-	char *host;
+	char *userhost;
 	int hostquery;
 	int ircop;
 	int chanop;
@@ -367,7 +373,7 @@ struct chanuser {
 struct botuser {
 	char *handle;
 	char *options;
-	char password[TINYSTRINGLEN + 1];
+	char *password;
 	struct maskstruct *firstmask;
 	struct botuser *prev;
 	struct botuser *next;
@@ -376,7 +382,7 @@ struct botuser {
 struct authed {
 	time_t at;
 	struct botuser *user;
-	char host[HOSTLEN + 1];
+	char *userhost;
 	struct authed *prev;
 	struct authed *next;
 };
@@ -423,7 +429,7 @@ struct ls_wrapstruct {
 struct pubmsg {
 	time_t at;
 	char *nick;
-	char *host;
+	char *userhost;
 	char *message;
 	struct pubmsg *prev;
 	struct pubmsg *next;
@@ -432,7 +438,7 @@ struct pubmsg {
 struct join {
 	time_t at;
 	char *nick;
-	char *host;
+	char *userhost;
 	struct join *prev;
 	struct join *next;
 };
@@ -441,7 +447,7 @@ struct part {
 	time_t at;
 	int valid;
 	char *nick;
-	char *host;
+	char *userhost;
 	struct part *prev;
 	struct part *next;
 };
@@ -454,7 +460,7 @@ struct maskstruct {
 };
 
 struct advert {
-	char type[TINYSTRINGLEN + 1];
+	char *to;
 	char *message;
 	struct advert *prev;
 	struct advert *next;
@@ -491,6 +497,7 @@ struct channel {
 	int topic_change;
 	int topic_list;
 	int synced;
+	int bantype;
 	time_t rejoin_at;
 	time_t last_quote;
 	FILE *seen;
